#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # cartopy
# 
# *cartopy* aims at drawing maps based on [matplotlib](http://matplotlib.org/). It superimposes a geographical coordinate system on the top of matplotlib's one. It is usually used with modules such as [pyproj](https://jswhit.github.io/pyproj/) to handle [shapefiles](https://en.wikipedia.org/wiki/Shapefile) also with [shapely](https://github.com/Toblerity/Shapely) or [geopandas](http://geopandas.org/index.html), [fiona](http://toblerity.org/fiona/), [descartes](https://bitbucket.org/sgillies/descartes/).

# [documentation](https://scitools.org.uk/cartopy/docs/latest/) [source](https://github.com/SciTools/cartopy) [installation](https://github.com/SciTools/cartopy/blob/master/INSTALL) [tutorial](https://scitools.org.uk/cartopy/docs/latest/tutorials/understanding_transform.html#understanding-transform) [gallery](https://scitools.org.uk/cartopy/docs/latest/gallery/index.html)

# In[1]:


get_ipython().run_line_magic('matplotlib', 'inline')


# In[2]:


from jyquickhelper import add_notebook_menu
add_notebook_menu()


# ## example

# In[3]:


import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib.pyplot as plt

fig = plt.figure(figsize=(7,7))
ax = fig.add_subplot(1, 1, 1, projection=ccrs.PlateCarree())
ax.set_extent([-5, 10, 42, 52])

ax.add_feature(cfeature.OCEAN)
ax.add_feature(cfeature.COASTLINE)
ax.add_feature(cfeature.RIVERS)
ax.add_feature(cfeature.LAKES)
ax.add_feature(cfeature.LAND)
ax.add_feature(cfeature.BORDERS, linestyle=':')
ax.plot([2.35, 2.20], [48.85, 48.71], '.')
ax.text(2.35, 48.85, "Paris")
ax.text(2.20, 48.71, "Saclay", ha="right")
ax.set_title('France');


# In[4]: